@@ -144,8 +144,8 @@ init_dbus (NMObject *object)
 	                                property_info);
 
 	proxy = _nm_object_get_proxy (object, NM_DBUS_INTERFACE_VPN_CONNECTION);
-	g_signal_connect (proxy, "vpn-state-changed",
-	                  G_CALLBACK (vpn_state_changed_proxy), object);
+	g_signal_connect_object (proxy, "vpn-state-changed",
+	                         G_CALLBACK (vpn_state_changed_proxy), object, 0);
 	g_object_unref (proxy);
 }
 
