@@ -28,7 +28,7 @@
 #include <gmodule.h>
 
 #include "nm-setting-connection.h"
-#include "nm-settings-plugin.h"
+#include "settings/nm-settings-plugin.h"
 #include "NetworkManagerUtils.h"
 
 #include "nms-ibft-reader.h"
@@ -202,5 +202,5 @@ settings_plugin_interface_init (NMSettingsPluginInterface *plugin_iface)
 G_MODULE_EXPORT GObject *
 nm_settings_plugin_factory (void)
 {
-	return g_object_ref (nms_ibft_plugin_get ());
+	return G_OBJECT (g_object_ref (nms_ibft_plugin_get ()));
 }
